/******************************************************************
********* This .do file runs the regressions 	     **************
********* used in the paper. 						 ******
*******************************************************************/


/***********************************************************************
This .do file uses the STATA package "est2tex".  Download by:
"net install est2tex, from(http://econ.ucsd.edu/muendler/download/stata)".  
*************************************************************************/




drop _all
set mem 100m
set more off

set scheme s2manual

use TanzPanel

gen InRegression=.

/* First, generate the headings. */


gen AgeEarningsHeading=.
label var AgeEarningsHeading "\textbf{\emph{\underline{Age and tenure:}}}"
gen EducationHeading=.
label var EducationHeading "\textbf{\emph{\underline{Education:}}}"
gen OccupationHeading=.
label var OccupationHeading "\textbf{\emph{\underline{Occupation characteristics:}}}"
gen OccupationChangeHeading=.
label var OccupationChangeHeading "\textbf{\emph{\underline{Change in occupation characteristics:}}}"
gen OtherHeading=.
label var OtherHeading "\textbf{\underline{\emph{Other:}}}"
gen InstrHeading=.
label var InstrHeading "\textbf{\underline{\emph{Instruments:}}}"
gen InsertLine=.
label var InsertLine "\hline"
gen InsertBlank=.
label var InsertBlank " "
gen DepVarLabel=.


/* Regression set 1: Levels of earnings, education measured by a continuous variable (educ) and by categorical variables. */

label var DepVarLabel "\textbf{Dependent variable: \emph{Log earnings}}"

replace InRegression=1

reg logearn male educ age agesqdiv100 tenure tensqdiv100 Lemployees Lfirmsize ///
	Doccup1-Doccup3 Tanz05 Tanz06 RegionD1-RegionD5 if InRegression, robust
est2vec LevelsAllP1, replace e(N r2) vars(InsertBlank DepVarLabel InsertLine AgeEarningsHeading age agesqdiv100 tenure tensqdiv100 ///
	EducationHeading educ educsqdiv100 CeduclevelD1 CeduclevelD2 CeduclevelD3 CeduclevelD4 CeduclevelD5) name(A)
est2vec LevelsAllP2, replace e(N r2) vars(OccupationHeading Lemployees Lfirmsize Doccup1 Doccup2 Doccup3 ///
	OtherHeading Tanz05 Tanz06 RegionD1 RegionD2 RegionD3 RegionD4 RegionD5 male _cons InsertLine) name(A)

reg logearn male educ age agesqdiv100 tenure tensqdiv100 Lemployees Tanz05 Tanz06 /// 
	RegionD1-RegionD5 if wage==0 & InRegression, robust
est2vec LevelsAllP1, addto(LevelsAllP1) name (B)
est2vec LevelsAllP2, addto(LevelsAllP2) name (B)

reg logearn male educ Doccup1-Doccup2 age agesqdiv100 tenure tensqdiv100 Lfirmsize Tanz05 Tanz06 ///
	RegionD1-RegionD5 if wage==1 & InRegression, robust
est2vec LevelsAllP1, addto(LevelsAllP1) name (C)
est2vec LevelsAllP2, addto(LevelsAllP2) name (C)


reg logearn male educ educsqdiv100 age agesqdiv100 tenure tensqdiv100 Lemployees Lfirmsize ///
	Doccup1-Doccup3 Tanz05 Tanz06 RegionD1-RegionD5 if InRegression, robust
est2vec LevelsAllP1, addto(LevelsAllP1) name (D)
est2vec LevelsAllP2, addto(LevelsAllP2) name (D)

reg logearn male educ educsqdiv100 age agesqdiv100 tenure tensqdiv100 Lemployees Tanz05 Tanz06 /// 
	RegionD1-RegionD5 if wage==0 & InRegression, robust
est2vec LevelsAllP1, addto(LevelsAllP1) name (E)
est2vec LevelsAllP2, addto(LevelsAllP2) name (E)

reg logearn male educ educsqdiv100 Doccup1-Doccup2 age agesqdiv100 tenure tensqdiv100 Lfirmsize Tanz05 Tanz06 ///
	RegionD1-RegionD5 if wage==1 & InRegression, robust
est2vec LevelsAllP1, addto(LevelsAllP1) name (F)
est2vec LevelsAllP2, addto(LevelsAllP2) name (F)


reg logearn male CeduclevelD1-CeduclevelD5 age agesqdiv100 tenure tensqdiv100 Lemployees Lfirmsize ///
	Doccup1-Doccup3 Tanz05 Tanz06 RegionD1-RegionD5 if InRegression, robust

est2vec LevelsAllP1, addto(LevelsAllP1) name (G)
est2vec LevelsAllP2, addto(LevelsAllP2) name (G)


reg logearn male CeduclevelD1-CeduclevelD5 age agesqdiv100 tenure tensqdiv100 Lemployees Tanz05 Tanz06 /// 
	RegionD1-RegionD5 if wage==0 & InRegression, robust
est2vec LevelsAllP1, addto(LevelsAllP1) name (H)
est2vec LevelsAllP2, addto(LevelsAllP2) name (H)

reg logearn male CeduclevelD1-CeduclevelD5 Doccup1-Doccup2 age agesqdiv100 tenure tensqdiv100 Lfirmsize Tanz05 Tanz06 ///
	RegionD1-RegionD5 if wage==1 & InRegression, robust
est2vec LevelsAllP1, addto(LevelsAllP1) name (I)
est2vec LevelsAllP2, addto(LevelsAllP2) name (I)



matrix drop LevelsAllP1_e

est2tex LevelsAllP1, preserve levels (90 95 99) mark(stars) fancy label replace leadzero collabels ///
	 (Pooled~1 Self-Emp.~1 Wage~1 Pooled~2 Self-Emp.~2 Wage~2 Pooled~3 Self-Emp.~3 Wage~3)
est2tex LevelsAllP2, preserve levels (90 95 99) mark(stars) fancy label replace leadzero collabels ///
	(Pooled~1 Self-Emp.~1 Wage~1 Pooled~2 Self-Emp.~2 Wage~2 Pooled~3 Self-Emp.~3 Wage~3)



/* Regression set 2: Levels of earnings, disaggregated across occupation. */

label var Tanz05 "Time dummy, 2005

label var DepVarLabel "\textbf{Dependent variable: \emph{Log earnings}}"

replace InRegression=1

reg logearn male CeduclevelD1-CeduclevelD5 age agesqdiv100 tenure tensqdiv100 Lemployees Lfirmsize ///
	Doccup1-Doccup3 Tanz05 Tanz06 RegionD1-RegionD5 if InRegression, robust

est2vec PSLevelsAllP1, replace e(N r2) vars(InsertBlank DepVarLabel InsertLine AgeEarningsHeading age agesqdiv100 tenure tensqdiv100 ///
	EducationHeading CeduclevelD1 CeduclevelD2 CeduclevelD3 CeduclevelD4 CeduclevelD5) name(A)
est2vec PSLevelsAllP2, replace e(N r2) vars(OccupationHeading Lemployees Lfirmsize Doccup1 Doccup2 Doccup3 ///
	OtherHeading Tanz05 Tanz06 RegionD1 RegionD2 RegionD3 RegionD4 RegionD5 male _cons InsertLine) name(A)

reg logearn male CeduclevelD1-CeduclevelD5 age agesqdiv100 tenure tensqdiv100 Lemployees Tanz05 Tanz06 /// 
	RegionD1-RegionD5 if wage==0 & InRegression, robust
est2vec PSLevelsAllP1, addto(PSLevelsAllP1) name (B)
est2vec PSLevelsAllP2, addto(PSLevelsAllP2) name (B)

reg logearn male CeduclevelD1-CeduclevelD5 Doccup1-Doccup2 age agesqdiv100 tenure tensqdiv100 Lfirmsize Tanz05 Tanz06 ///
	RegionD1-RegionD5 if wage==1 & InRegression, robust
est2vec PSLevelsAllP1, addto(PSLevelsAllP1) name (C)
est2vec PSLevelsAllP2, addto(PSLevelsAllP2) name (C)

reg logearn male CeduclevelD1-CeduclevelD5 Doccup1-Doccup2 age agesqdiv100 tenure tensqdiv100 Lfirmsize Tanz05 Tanz06 ///
	RegionD1-RegionD5 if Doccup1==1 & InRegression, robust
est2vec PSLevelsAllP1, addto(PSLevelsAllP1) name (D)
est2vec PSLevelsAllP2, addto(PSLevelsAllP2) name (D)

reg logearn male CeduclevelD1-CeduclevelD5 Doccup1-Doccup2 age agesqdiv100 tenure tensqdiv100 Lfirmsize Tanz05 Tanz06 ///
	RegionD1-RegionD5 if Doccup2==1 & InRegression, robust
est2vec PSLevelsAllP1, addto(PSLevelsAllP1) name (E)
est2vec PSLevelsAllP2, addto(PSLevelsAllP2) name (E)

reg logearn male CeduclevelD1-CeduclevelD5 Doccup1-Doccup2 age agesqdiv100 tenure tensqdiv100 Lfirmsize Tanz05 Tanz06 ///
	RegionD1-RegionD5 if Doccup3==1 & InRegression, robust
est2vec PSLevelsAllP1, addto(PSLevelsAllP1) name (F)
est2vec PSLevelsAllP2, addto(PSLevelsAllP2) name (F)


matrix drop PSLevelsAllP1_e

est2tex PSLevelsAllP1, preserve levels (90 95 99) mark(stars) fancy label replace leadzero collabels ///
	 (Pooled Self-Employed Wage Civil Public Private)
est2tex PSLevelsAllP2, preserve levels (90 95 99) mark(stars) fancy label replace leadzero collabels ///
	(Pooled Self-Employed Wage Civil Public Private)



/* Regression set 3: First-stage selection regresion. */


replace InRegression=0
replace InRegression=1 if Tanz04

label var DepVarLabel "\textbf{Dependent variable: \emph{Sample retention}}"

probit Have05 logearn age agesqdiv100 tenure tensqdiv100 CeduclevelD1 CeduclevelD2 CeduclevelD3 CeduclevelD4 CeduclevelD5 ///
	Lemployees Lfirmsize Doccup1-Doccup3 RegionD1-RegionD5 male if InRegression

est2vec IVPFirstStageP1, replace e(N r2_p) vars(InsertBlank DepVarLabel InsertLine logearn AgeEarningsHeading age agesqdiv100 tenure tensqdiv100 ///
	EducationHeading CeduclevelD1 CeduclevelD2 CeduclevelD3 CeduclevelD4 CeduclevelD5)
	
est2vec IVPFirstStageP2, replace e(N r2_p) vars(OccupationHeading Lemployees Lfirmsize Doccup1 Doccup2 Doccup3 ///
	OtherHeading RegionD1 RegionD2 RegionD3 RegionD4 RegionD5 male _cons InsertLine)

predict Correct05Predict if e(sample)
egen Correct05Predictsum = sum(Correct05Predict), by(wid)
replace Correct05Predict = Correct05Predictsum
replace Correct05Predict=0 if Tanz04 | Tanz06


mfx
matrix MarginalBeta = e(Xmfx_dydx)'
matrix MarginalBetaSE = e(Xmfx_se_dydx)'

est2vec IVPFirstStageP1, addto(IVPFirstStageP1) name(B)
est2vec IVPFirstStageP2, addto(IVPFirstStageP2) name(B)

matrix IVPFirstStageP1_b[4, 2] = MarginalBeta[1, 1]
matrix IVPFirstStageP1_b[6, 2] = MarginalBeta[2, 1]
matrix IVPFirstStageP1_b[7, 2] = MarginalBeta[3, 1]
matrix IVPFirstStageP1_b[8, 2] = MarginalBeta[4, 1]
matrix IVPFirstStageP1_b[9, 2] = MarginalBeta[5, 1]
matrix IVPFirstStageP1_b[11, 2] = MarginalBeta[6, 1]
matrix IVPFirstStageP1_b[12, 2] = MarginalBeta[7, 1]
matrix IVPFirstStageP1_b[13, 2] = MarginalBeta[8, 1]
matrix IVPFirstStageP1_b[14, 2] = MarginalBeta[9, 1]

matrix IVPFirstStageP2_b[2, 2] = MarginalBeta[10, 1]
matrix IVPFirstStageP2_b[3, 2] = MarginalBeta[11, 1]
matrix IVPFirstStageP2_b[4, 2] = MarginalBeta[12, 1]
matrix IVPFirstStageP2_b[5, 2] = MarginalBeta[13, 1]
matrix IVPFirstStageP2_b[6, 2] = MarginalBeta[14, 1]
matrix IVPFirstStageP2_b[8, 2] = MarginalBeta[15, 1]
matrix IVPFirstStageP2_b[9, 2] = MarginalBeta[16, 1]
matrix IVPFirstStageP2_b[10, 2] = MarginalBeta[17, 1]
matrix IVPFirstStageP2_b[11, 2] = MarginalBeta[18, 1]
matrix IVPFirstStageP2_b[12, 2] = MarginalBeta[19, 1]
matrix IVPFirstStageP2_b[13, 2] = MarginalBeta[20, 1]
matrix IVPFirstStageP2_b[14, 2] = -999


matrix IVPFirstStageP1_se[4, 2] = MarginalBetaSE[1, 1]
matrix IVPFirstStageP1_se[6, 2] = MarginalBetaSE[2, 1]
matrix IVPFirstStageP1_se[7, 2] = MarginalBetaSE[3, 1]
matrix IVPFirstStageP1_se[8, 2] = MarginalBetaSE[4, 1]
matrix IVPFirstStageP1_se[9, 2] = MarginalBetaSE[5, 1]
matrix IVPFirstStageP1_se[11, 2] = MarginalBetaSE[6, 1]
matrix IVPFirstStageP1_se[12, 2] = MarginalBetaSE[7, 1]
matrix IVPFirstStageP1_se[13, 2] = MarginalBetaSE[8, 1]
matrix IVPFirstStageP1_se[14, 2] = MarginalBetaSE[9, 1]

matrix IVPFirstStageP2_se[2, 2] = MarginalBetaSE[10, 1]
matrix IVPFirstStageP2_se[3, 2] = MarginalBetaSE[11, 1]
matrix IVPFirstStageP2_se[4, 2] = MarginalBetaSE[12, 1]
matrix IVPFirstStageP2_se[5, 2] = MarginalBetaSE[13, 1]
matrix IVPFirstStageP2_se[6, 2] = MarginalBetaSE[14, 1]
matrix IVPFirstStageP2_se[8, 2] = MarginalBetaSE[15, 1]
matrix IVPFirstStageP2_se[9, 2] = MarginalBetaSE[16, 1]
matrix IVPFirstStageP2_se[10, 2] = MarginalBetaSE[17, 1]
matrix IVPFirstStageP2_se[11, 2] = MarginalBetaSE[18, 1]
matrix IVPFirstStageP2_se[12, 2] = MarginalBetaSE[19, 1]
matrix IVPFirstStageP2_se[13, 2] = MarginalBetaSE[20, 1]
matrix IVPFirstStageP2_se[14, 2] = -999

matrix drop MarginalBeta
matrix drop MarginalBetaSE


gen HaveAll = 0
replace HaveAll = 1 if Have04 & Have05 & Have06

probit HaveAll logearn age agesqdiv100 tenure tensqdiv100 CeduclevelD1 CeduclevelD2 CeduclevelD3 CeduclevelD4 CeduclevelD5 ///
	Lemployees Lfirmsize Doccup1-Doccup3 RegionD1-RegionD5 male if InRegression

mfx

matrix MarginalBeta = e(Xmfx_dydx)'
matrix MarginalBetaSE = e(Xmfx_se_dydx)'


est2vec IVPFirstStageP1, addto(IVPFirstStageP1) name(C)
est2vec IVPFirstStageP2, addto(IVPFirstStageP2) name(C)

est2vec IVPFirstStageP1, addto(IVPFirstStageP1) name(D)
est2vec IVPFirstStageP2, addto(IVPFirstStageP2) name(D)

matrix IVPFirstStageP1_b[4, 4] = MarginalBeta[1, 1]
matrix IVPFirstStageP1_b[6, 4] = MarginalBeta[2, 1]
matrix IVPFirstStageP1_b[7, 4] = MarginalBeta[3, 1]
matrix IVPFirstStageP1_b[8, 4] = MarginalBeta[4, 1]
matrix IVPFirstStageP1_b[9, 4] = MarginalBeta[5, 1]
matrix IVPFirstStageP1_b[11, 4] = MarginalBeta[6, 1]
matrix IVPFirstStageP1_b[12, 4] = MarginalBeta[7, 1]
matrix IVPFirstStageP1_b[13, 4] = MarginalBeta[8, 1]
matrix IVPFirstStageP1_b[14, 4] = MarginalBeta[9, 1]
matrix IVPFirstStageP1_b[15, 4] = MarginalBeta[10, 1]

matrix IVPFirstStageP2_b[2, 4] = MarginalBeta[11, 1]
matrix IVPFirstStageP2_b[3, 4] = MarginalBeta[12, 1]
matrix IVPFirstStageP2_b[4, 4] = MarginalBeta[13, 1]
matrix IVPFirstStageP2_b[5, 4] = MarginalBeta[14, 1]
matrix IVPFirstStageP2_b[6, 4] = MarginalBeta[15, 1]
matrix IVPFirstStageP2_b[8, 4] = MarginalBeta[16, 1]
matrix IVPFirstStageP2_b[9, 4] = MarginalBeta[17, 1]
matrix IVPFirstStageP2_b[10, 4] = MarginalBeta[18, 1]
matrix IVPFirstStageP2_b[11, 4] = MarginalBeta[19, 1]
matrix IVPFirstStageP2_b[12, 4] = MarginalBeta[20, 1]
matrix IVPFirstStageP2_b[13, 4] = MarginalBeta[21, 1]
matrix IVPFirstStageP2_b[14, 4] = -999


matrix IVPFirstStageP1_se[4, 4] = MarginalBetaSE[1, 1]
matrix IVPFirstStageP1_se[6, 4] = MarginalBetaSE[2, 1]
matrix IVPFirstStageP1_se[7, 4] = MarginalBetaSE[3, 1]
matrix IVPFirstStageP1_se[8, 4] = MarginalBetaSE[4, 1]
matrix IVPFirstStageP1_se[9, 4] = MarginalBetaSE[5, 1]
matrix IVPFirstStageP1_se[11, 4] = MarginalBetaSE[6, 1]
matrix IVPFirstStageP1_se[12, 4] = MarginalBetaSE[7, 1]
matrix IVPFirstStageP1_se[13, 4] = MarginalBetaSE[8, 1]
matrix IVPFirstStageP1_se[14, 4] = MarginalBetaSE[9, 1]
matrix IVPFirstStageP1_se[15, 4] = MarginalBetaSE[10, 1]

matrix IVPFirstStageP2_se[2, 4] = MarginalBetaSE[11, 1]
matrix IVPFirstStageP2_se[3, 4] = MarginalBetaSE[12, 1]
matrix IVPFirstStageP2_se[4, 4] = MarginalBetaSE[13, 1]
matrix IVPFirstStageP2_se[5, 4] = MarginalBetaSE[14, 1]
matrix IVPFirstStageP2_se[6, 4] = MarginalBetaSE[15, 1]
matrix IVPFirstStageP2_se[8, 4] = MarginalBetaSE[16, 1]
matrix IVPFirstStageP2_se[9, 4] = MarginalBetaSE[17, 1]
matrix IVPFirstStageP2_se[10, 4] = MarginalBetaSE[18, 1]
matrix IVPFirstStageP2_se[11, 4] = MarginalBetaSE[19, 1]
matrix IVPFirstStageP2_se[12, 4] = MarginalBetaSE[20, 1]
matrix IVPFirstStageP2_se[13, 4] = MarginalBetaSE[21, 1]
matrix IVPFirstStageP2_se[14, 4] = -999



predict Correct06Predict if e(sample)
egen Correct06Predictsum = sum(Correct06Predict), by(wid)
replace Correct06Predict = Correct06Predictsum
replace Correct06Predict=0 if Tanz04 | Tanz05


matrix drop IVPFirstStageP1_e

matrix IVPFirstStageP2_e[1,2]=-999
matrix IVPFirstStageP2_e[2,2]=-999
matrix IVPFirstStageP2_e[1,4]=-999
matrix IVPFirstStageP2_e[2,4]=-999

matrix rownames IVPFirstStageP2_e = "e(N)" "e(r2)"

est2tex IVPFirstStageP1, preserve levels (90 95 99) mark(stars) fancy label replace leadzero ///
	collabels (2005~(coefficients) 2005~(marginal~effects) 2005~and~2006~(coefficients) 2005~and~2006~(marginal~effects))
est2tex IVPFirstStageP2, preserve levels (90 95 99) mark(stars) fancy label replace leadzero ///
	collabels (2005~(coefficients) 2005~(marginal~effects) 2005~and~2006~(coefficients) 2005~and~2006~(marginal~effects))



/* Regression set 4: Second-stage levels regression, inverse probability weighting. */
 

gen IPWeight=1
replace IPWeight=1/Correct05Predict if Tanz05
replace IPWeight=1/Correct06Predict if Tanz06

replace IPWeight=1 if IPWeight==. & CeduclevelD5==1

replace InRegression=0
replace InRegression=1 if Have04


label var DepVarLabel "\textbf{Dependent variable: \emph{Log earnings}}"

reg logearn male CeduclevelD1-CeduclevelD5 age agesqdiv100 tenure tensqdiv100 Lemployees Lfirmsize ///
	Doccup1-Doccup3 Tanz05 Tanz06 RegionD1-RegionD5 if InRegression, robust

est2vec SelectPSLevelsAllP1, replace e(N r2 ll) vars(InsertBlank DepVarLabel InsertLine AgeEarningsHeading age agesqdiv100 tenure tensqdiv100 ///
	EducationHeading CeduclevelD1 CeduclevelD2 CeduclevelD3 CeduclevelD4 CeduclevelD5) name(A)
est2vec SelectPSLevelsAllP2, replace e(N r2 ll) vars(OccupationHeading Lemployees Lfirmsize Doccup1 Doccup2 Doccup3 ///
	OtherHeading Tanz05 Tanz06 RegionD1 RegionD2 RegionD3 RegionD4 RegionD5 male _cons InsertLine) name(A)

reg logearn male CeduclevelD1-CeduclevelD5 age agesqdiv100 tenure tensqdiv100 Lemployees Tanz05 Tanz06 /// 
	RegionD1-RegionD5 if wage==0 & InRegression, robust
est2vec SelectPSLevelsAllP1, addto(SelectPSLevelsAllP1) name (B)
est2vec SelectPSLevelsAllP2, addto(SelectPSLevelsAllP2) name (B)

reg logearn male CeduclevelD1-CeduclevelD5 Doccup1-Doccup2 age agesqdiv100 tenure tensqdiv100 Lfirmsize Tanz05 Tanz06 ///
	RegionD1-RegionD5 if wage==1 & InRegression, robust
est2vec SelectPSLevelsAllP1, addto(SelectPSLevelsAllP1) name (C)
est2vec SelectPSLevelsAllP2, addto(SelectPSLevelsAllP2) name (C)

reg logearn male CeduclevelD1-CeduclevelD5 age agesqdiv100 tenure tensqdiv100 Lemployees Lfirmsize ///
	Doccup1-Doccup3 Tanz05 Tanz06 RegionD1-RegionD5 [pweight=IPWeight] if InRegression, robust

est2vec SelectPSLevelsAllP1, addto(SelectPSLevelsAllP1) name (D)
est2vec SelectPSLevelsAllP2, addto(SelectPSLevelsAllP2) name (D)

reg logearn male CeduclevelD1-CeduclevelD5 age agesqdiv100 tenure tensqdiv100 Lemployees Tanz05 Tanz06 /// 
	RegionD1-RegionD5 [pweight=IPWeight] if wage==0 & InRegression, robust
est2vec SelectPSLevelsAllP1, addto(SelectPSLevelsAllP1) name (E)
est2vec SelectPSLevelsAllP2, addto(SelectPSLevelsAllP2) name (E)

reg logearn male CeduclevelD1-CeduclevelD5 Doccup1-Doccup2 age agesqdiv100 tenure tensqdiv100 Lfirmsize Tanz05 Tanz06 ///
	RegionD1-RegionD5 [pweight=IPWeight] if wage==1 & InRegression, robust
est2vec SelectPSLevelsAllP1, addto(SelectPSLevelsAllP1) name (F)
est2vec SelectPSLevelsAllP2, addto(SelectPSLevelsAllP2) name (F)


matrix drop SelectPSLevelsAllP1_e

matrix rownames SelectPSLevelsAllP2_e = "e(N)" "e(r2)" "Log-likelihood"

est2tex SelectPSLevelsAllP1, preserve levels (90 95 99) mark(stars) fancy label replace leadzero ///
 	collabels (Pooled Self-Emp. Wage Pooled~(IPW) Self-Emp.~(IPW) Wage~(IPW))
est2tex SelectPSLevelsAllP2, preserve levels (90 95 99) mark(stars) fancy label replace leadzero ///
 	collabels (Pooled Self-Emp. Wage Pooled~(IPW) Self-Emp.~(IPW) Wage~(IPW))


reg logearn male educ educsqdiv100 age agesqdiv100 tenure tensqdiv100 Lemployees Lfirmsize ///
	Doccup1-Doccup3 Tanz05 Tanz06 RegionD1-RegionD5 if InRegression, robust
est2vec SelectLevelsAllP1, replace e(N r2 ll) vars(InsertBlank DepVarLabel InsertLine AgeEarningsHeading age agesqdiv100 tenure tensqdiv100 ///
	EducationHeading educ educsqdiv100) name(A)
est2vec SelectLevelsAllP2, replace e(N r2 ll) vars(OccupationHeading Lemployees Lfirmsize Doccup1 Doccup2 Doccup3 ///
	OtherHeading Tanz05 Tanz06 RegionD1 RegionD2 RegionD3 RegionD4 RegionD5 male _cons InsertLine) name(A)

reg logearn male educ educsqdiv100 age agesqdiv100 tenure tensqdiv100 Lemployees Tanz05 Tanz06 /// 
	RegionD1-RegionD5 if wage==0 & InRegression, robust
est2vec SelectLevelsAllP1, addto(SelectLevelsAllP1) name (B)
est2vec SelectLevelsAllP2, addto(SelectLevelsAllP2) name (B)

reg logearn male educ educsqdiv100 Doccup1-Doccup2 age agesqdiv100 tenure tensqdiv100 Lfirmsize Tanz05 Tanz06 ///
	RegionD1-RegionD5 if wage==1 & InRegression, robust
est2vec SelectLevelsAllP1, addto(SelectLevelsAllP1) name (C)
est2vec SelectLevelsAllP2, addto(SelectLevelsAllP2) name (C)


reg logearn male educ educsqdiv100 age agesqdiv100 tenure tensqdiv100 Lemployees Lfirmsize ///
	Doccup1-Doccup3 Tanz05 Tanz06 RegionD1-RegionD5 [pweight=IPWeight] if InRegression, robust
est2vec SelectLevelsAllP1, addto(SelectLevelsAllP1) name (D)
est2vec SelectLevelsAllP2, addto(SelectLevelsAllP2) name (D)

reg logearn male educ educsqdiv100 age agesqdiv100 tenure tensqdiv100 Lemployees Tanz05 Tanz06 /// 
	RegionD1-RegionD5 [pweight=IPWeight] if wage==0 & InRegression, robust
est2vec SelectLevelsAllP1, addto(SelectLevelsAllP1) name (E)
est2vec SelectLevelsAllP2, addto(SelectLevelsAllP2) name (E)

reg logearn male educ educsqdiv100 Doccup1-Doccup2 age agesqdiv100 tenure tensqdiv100 Lfirmsize Tanz05 Tanz06 ///
	RegionD1-RegionD5 [pweight=IPWeight] if wage==1 & InRegression, robust
est2vec SelectLevelsAllP1, addto(SelectLevelsAllP1) name (F)
est2vec SelectLevelsAllP2, addto(SelectLevelsAllP2) name (F)




matrix drop SelectLevelsAllP1_e

est2tex SelectLevelsAllP1, preserve levels (90 95 99) mark(stars) fancy label replace leadzero collabels ///
	 (Pooled Self-Emp. Wage Pooled~(IPW) Self-Emp.~(IPW) Wage~(IPW))
est2tex SelectLevelsAllP2, preserve levels (90 95 99) mark(stars) fancy label replace leadzero collabels ///
	 (Pooled Self-Emp. Wage Pooled~(IPW) Self-Emp.~(IPW) Wage~(IPW))



/* Regression set 5: OLS of one-year growth in earnings. */

 

label var Tanz05 "Time dummy, 2005-2006 (reference: 2004-2005)"

label var DepVarLabel "\textbf{Dependent variable: \emph{One-year change in log earnings}}"

reg EarnGrowth1yr male age CeduclevelD1-CeduclevelD5 DLfirmsize1yr DLemployees1yr ///
	MoveInWage1yr MoveWageSelf1yr MoveSelfWage1yr ///
	RegionD1-RegionD5 Tanz05 Lemployees Lfirmsize Doccup1-Doccup3

est2vec PSGrowthReg1yr4P1, replace e(N r2) vars(InsertBlank DepVarLabel InsertLine AgeEarningsHeading age ///
	EducationHeading CeduclevelD1 CeduclevelD2 CeduclevelD3 CeduclevelD4 CeduclevelD5 ///
	OccupationHeading Lemployees Lfirmsize Doccup1 Doccup2 Doccup3) name(A)
 	

est2vec PSGrowthReg1yr4P2, replace e(N r2) vars(OccupationChangeHeading DLemployees1yr DLfirmsize1yr ///
	MoveInWage1yr MoveWageSelf1yr MoveSelfWage1yr ///
	OtherHeading RegionD1 RegionD2 RegionD3 RegionD4 RegionD5 Tanz05 male _cons InsertLine) name(A)

reg EarnGrowth1yr male age CeduclevelD1-CeduclevelD5 DLfirmsize1yr DLemployees1yr ///
	MoveInWage1yr MoveWageSelf1yr MoveSelfWage1yr ///
	RegionD1-RegionD5 ShiftS31yr Tanz05 Lfirmsize Lemployees Doccup1-Doccup3 if wage==0

est2vec PSGrowthReg1yr4P1, addto(PSGrowthReg1yr4P1) name(B)
est2vec PSGrowthReg1yr4P2, addto(PSGrowthReg1yr4P2) name(B)

reg EarnGrowth1yr male age CeduclevelD1-CeduclevelD5 DLfirmsize1yr DLemployees1yr ///
	MoveInWage1yr MoveWageSelf1yr MoveSelfWage1yr ///
	RegionD1-RegionD5 ShiftS31yr Tanz05 Lfirmsize Lemployees Doccup1-Doccup2 if wage==1

est2vec PSGrowthReg1yr4P1, addto(PSGrowthReg1yr4P1) name(C)
est2vec PSGrowthReg1yr4P2, addto(PSGrowthReg1yr4P2) name(C)


reg EarnGrowth1yr male age CeduclevelD1-CeduclevelD5 DLfirmsize1yr DLemployees1yr ///
	MoveInWage1yr MoveWageSelf1yr MoveSelfWage1yr ///
	RegionD1-RegionD5 ShiftS31yr Tanz05 Lfirmsize Lemployees Doccup1-Doccup3 if Doccup1==1

est2vec PSGrowthReg1yr4P1, addto(PSGrowthReg1yr4P1) name(D)
est2vec PSGrowthReg1yr4P2, addto(PSGrowthReg1yr4P2) name(D)

reg EarnGrowth1yr male age CeduclevelD1-CeduclevelD5 DLfirmsize1yr DLemployees1yr ///
	MoveInWage1yr MoveWageSelf1yr MoveSelfWage1yr ///
	RegionD1-RegionD5 ShiftS31yr Tanz05 Lfirmsize Lemployees Doccup1-Doccup3 if Doccup2==1

est2vec PSGrowthReg1yr4P1, addto(PSGrowthReg1yr4P1) name(E)
est2vec PSGrowthReg1yr4P2, addto(PSGrowthReg1yr4P2) name(E)

reg EarnGrowth1yr male age CeduclevelD1-CeduclevelD5 DLfirmsize1yr DLemployees1yr ///
	MoveInWage1yr MoveWageSelf1yr MoveSelfWage1yr ///
	RegionD1-RegionD5 ShiftS31yr Tanz05 Lfirmsize Lemployees Doccup1-Doccup3 if Doccup3==1
 
est2vec PSGrowthReg1yr4P1, addto(PSGrowthReg1yr4P1) name(F)
est2vec PSGrowthReg1yr4P2, addto(PSGrowthReg1yr4P2) name(F)


matrix drop PSGrowthReg1yr4P1_e

est2tex PSGrowthReg1yr4P1, preserve levels (90 95 99) mark(stars) fancy label replace leadzero collabels ///
	(Pooled Self-Employed Wage Civil Public Private)
est2tex PSGrowthReg1yr4P2, preserve levels (90 95 99) mark(stars) fancy label replace leadzero collabels ///
	(Pooled Self-Employed Wage Civil Public Private)


/* Regression set 6: Second-stage selection correction on the OLS growth regression. */


label var Tanz05 "Time dummy, 2005-2006 (reference: 2004-2005)"


replace IPWeight=1 if IPWeight==. & CeduclevelD5==1

gen IPWeight05=IPWeight if Tanz05
gen IPWeight06=IPWeight if Tanz06

*drop IPWeight

egen IPWeight05sum = sum(IPWeight05), by(wid)
egen IPWeight06sum = sum(IPWeight06), by(wid)

gen IPWeight2=IPWeight05sum if Tanz04
replace IPWeight2=IPWeight06sum if Tanz05

replace IPWeight2=. if IPWeight2==0

replace InRegression=0
replace InRegression=1 if Have04


label var DepVarLabel "\textbf{Dependent variable: \emph{One-year change in log earnings}}"

reg EarnGrowth1yr male age CeduclevelD1-CeduclevelD5 DLfirmsize1yr DLemployees1yr ///
	MoveInWage1yr MoveWageSelf1yr MoveSelfWage1yr ///
	RegionD1-RegionD5 Tanz05 Lfirmsize Lemployees Doccup1-Doccup3 if InRegression==1

est2vec SelectPSGrowthReg1yr4P1, replace e(N r2 ll) vars(InsertBlank DepVarLabel InsertLine AgeEarningsHeading age ///
	EducationHeading CeduclevelD1 CeduclevelD2 CeduclevelD3 CeduclevelD4 CeduclevelD5 OccupationHeading Lemployees Lfirmsize Doccup1 Doccup2 Doccup3) name(A)


est2vec SelectPSGrowthReg1yr4P2, replace e(N r2 ll) vars(OccupationChangeHeading DLemployees1yr DLfirmsize1yr ///
	MoveInWage1yr MoveWageSelf1yr MoveSelfWage1yr ///
	OtherHeading RegionD1 RegionD2 RegionD3 RegionD4 RegionD5 Tanz05 male _cons InsertLine) name(A)

reg EarnGrowth1yr male age CeduclevelD1-CeduclevelD5 DLfirmsize1yr DLemployees1yr ///
	MoveInWage1yr MoveWageSelf1yr MoveSelfWage1yr ///
	RegionD1-RegionD5 ShiftS31yr Tanz05 Lfirmsize Lemployees Doccup1-Doccup3 if wage==0 & InRegression==1


est2vec SelectPSGrowthReg1yr4P1, addto(SelectPSGrowthReg1yr4P1) name(B)
est2vec SelectPSGrowthReg1yr4P2, addto(SelectPSGrowthReg1yr4P2) name(B)

reg EarnGrowth1yr male age CeduclevelD1-CeduclevelD5 DLfirmsize1yr DLemployees1yr ///
	MoveInWage1yr MoveWageSelf1yr MoveSelfWage1yr ///
	RegionD1-RegionD5 ShiftS31yr Tanz05 Lfirmsize Lemployees Doccup1-Doccup2 if wage==1 & InRegression==1


est2vec SelectPSGrowthReg1yr4P1, addto(SelectPSGrowthReg1yr4P1) name(C)
est2vec SelectPSGrowthReg1yr4P2, addto(SelectPSGrowthReg1yr4P2) name(C)


reg EarnGrowth1yr male age CeduclevelD1-CeduclevelD5 DLfirmsize1yr DLemployees1yr ///
	MoveInWage1yr MoveWageSelf1yr MoveSelfWage1yr ///
	RegionD1-RegionD5 Tanz05 Lfirmsize Lemployees Doccup1-Doccup3 [pweight=IPWeight2] if InRegression==1


est2vec SelectPSGrowthReg1yr4P1, addto(SelectPSGrowthReg1yr4P1) name(D)
est2vec SelectPSGrowthReg1yr4P2, addto(SelectPSGrowthReg1yr4P2) name(D)

reg EarnGrowth1yr male age CeduclevelD1-CeduclevelD5 DLfirmsize1yr DLemployees1yr ///
	MoveInWage1yr MoveWageSelf1yr MoveSelfWage1yr ///
	RegionD1-RegionD5 ShiftS31yr Tanz05 Lfirmsize Lemployees Doccup1-Doccup3 [pweight=IPWeight2] if wage==0 & InRegression==1


est2vec SelectPSGrowthReg1yr4P1, addto(SelectPSGrowthReg1yr4P1) name(E)
est2vec SelectPSGrowthReg1yr4P2, addto(SelectPSGrowthReg1yr4P2) name(E)

reg EarnGrowth1yr male age CeduclevelD1-CeduclevelD5 DLfirmsize1yr DLemployees1yr ///
	MoveInWage1yr MoveWageSelf1yr MoveSelfWage1yr ///
	RegionD1-RegionD5 ShiftS31yr Tanz05 Lfirmsize Lemployees Doccup1-Doccup2 [pweight=IPWeight2] if wage==1 & InRegression==1

est2vec SelectPSGrowthReg1yr4P1, addto(SelectPSGrowthReg1yr4P1) name(F)
est2vec SelectPSGrowthReg1yr4P2, addto(SelectPSGrowthReg1yr4P2) name(F)



matrix drop SelectPSGrowthReg1yr4P1_e

matrix rownames SelectPSGrowthReg1yr4P2_e = "e(N)" "e(r2)" "Log-likelihood"

est2tex SelectPSGrowthReg1yr4P1, preserve levels (90 95 99) mark(stars) fancy label replace leadzero ///
	collabels (Pooled Self-Emp. Wage Pooled~(IPV) Self-Emp.~(IPV) Wage~(IPV))
est2tex SelectPSGrowthReg1yr4P2, preserve levels (90 95 99) mark(stars) fancy label replace leadzero ///
	collabels (Pooled Self-Emp. Wage Pooled~(IPV) Self-Emp.~(IPV) Wage~(IPV))


exit

